class BaseObject:
    def __init__(self, **kwargs):
        self.client_id = kwargs.pop('client_id', '7032158')
        self.username = kwargs.pop('username', 'clienttest')
        self.password = kwargs.pop('password', 'testing')

    @property
    def params(self):
        return {
            'username': self.username,
            'user_pass': self.password,
            'client_id': self.client_id,
        }



import requests

from fan_courier_client.common import BaseObject
from fan_courier_client.constants import MAIN_URL
from fan_courier_client.utils import csv_to_json


class Address(BaseObject):
    city_url = 'export_distante_integrat.php'
    addresses_url = 'export_strazi_integrat.php'

    def cities(self):
        response = requests.post(f'{MAIN_URL}/{self.city_url}', data=self.params)
        return csv_to_json(response.text)

    def get(self, **kwargs):
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.addresses_url}', data=kwargs)
        return csv_to_json(response.text)



import requests

from fan_courier_client.common import BaseObject
from fan_courier_client.constants import MAIN_URL
from fan_courier_client.decorators import validate
from fan_courier_client.services import Service


class Rate(BaseObject):
    rate_url = 'tarif.php'

    validation_fields = {
        'serviciu': {
            'type': str,
            'choices': Service().get(),
        },
        'localitate_dest': {
            'type': str
        },
        'judet_dest': {
            'type': str
        },
        'plicuri': {
            'type': int
        },
        'colete': {
            'type': int
        },
        'greutate': {
            'type': int
        },
        'lungime': {
            'type': int
        },
        'latime': {
            'type': int
        },
        'inaltime': {
            'type': int
        },
        'val_decl': {
            'type': int
        },
        'plata_ramburs': {
            'type': str,
            'choices': ['destinatar', 'expeditor']
        },
        'optiuni': {
            'type': str
        },
    }

    @validate(validation_fields)
    def get(self, **kwargs):
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.rate_url}', data=kwargs).text
        return int(response) if response.isdigit() else response



import requests
from .utils import *
from .constants import *
import csv, io, json, re

# CLIENT_ID = '695720'
# USERNAME = 'Zaharadji@mail.ru'
# PASSWORD = 'qwe123'
CLIENT_ID = '7032158'
USERNAME = 'clienttest'
PASSWORD = 'testing'

URL = MAIN_URL



params = {
    'username': USERNAME,
    'user_pass': PASSWORD,
    'client_id': CLIENT_ID,
}






# test


# test


def validate(fields):
    def decorator(func):
        def wrapper(**kwargs):
            for field in fields:
                if not kwargs.get(field):
                    raise Exception(f"Field '{field}' is required")
            return func(**kwargs)

        return wrapper

    return decorator


fields = ['tip_serviciu', 'iban', 'nr_plicuri', 'nr_colete', 'greutate', 'plata_expeditie', 'ramburs_bani',
          'plata_ramburs_la', 'nume_destinatar', 'telefon', 'judet', 'localitate', 'strada', 'cod_postal']

csv_headers = {
    'tip_serviciu': 'Tip serviciu',
    'banca': 'Banca',
    'iban': 'IBAN',
    'nr_plicuri': 'Nr. Plicuri',
    'nr_colete': 'Nr. Colete',
    'greutate': 'Greutate',
    'plata_expeditie': 'Plata expeditie',
    'ramburs_bani': 'Ramburs(bani)',
    'plata_ramburs_la': 'Plata ramburs la',
    'valoare_declarata': 'Valoare declarata',
    'persoana_contact_expeditor': 'Persoana contact expeditor',
    'observatii': 'Observatii',
    'continut': 'Continut',
    'nume_destinatar': 'Nume destinatar',
    'persoana_contact': 'Persoana contact',
    'telefon': 'Telefon',
    'fax': 'Fax',
    'email': 'Email',
    'judet': 'Judet',
    'localitate': 'Localitatea',
    'strada': 'Strada',
    'nr': 'Nr',
    'cod_postal': 'Cod postal',
    'bl': 'Bloc',
    'scara': 'Scara',
    'etaj': 'Etaj',
    'apartament': 'Apartament',
    'inaltime_pachet': 'Inaltime pachet',
    'latime_pachet': 'Latime pachet',
    'lungime_pachet': 'Latime pachet',
    'restituire': 'Restituire',
    'centru_cost': 'Centru Cost',
    'optiuni': 'Optiuni',
    'packing': 'Packing',
    'date_personale': 'Date personale',
}

request_data = {
    'tip_serviciu': 'Standard',
    'banca': 'Test',
    'iban': 'XXXXXXX',
    'nr_plicuri': 1,
    'nr_colete': 0,
    'greutate': 1,
    'plata_expeditie': 'ramburs',
    'rambursbani': 100,
    'plata_ramburs_la': 'destinatar',
    'valoare_declarata': 400,
    'persoana_contact_expeditor': 'Test User',
    'observatii': 'Lorem ipsum',
    'continut': 'Fragil',
    'nume_destinatar': 'Test',
    'persoana_contact': 'Test',
    'telefon': '123456789',
    'fax': '123456789',
    'email': 'example@example.com',
    'judet': 'Galati',
    'localitatea': 'Tecuci',
    'strada': 'Lorem',
    'nr': '2',
    'cod_postal': '123456',
    'bloc': '',
    'scara': '',
    'etaj': '',
    'apartament': '',
    'inaltime_pachet': '',
    'latime_pachet': '',
    'lungime_pachet': '',
    'restituire': '',
    'centru_cost': '',
    'optiuni': '',
    'packing': '',
    'date_personale': ''
}
@validate(fields)
def create_awb(**kwargs):
    csv_data = json_to_csv(kwargs, csv_headers)
    # request_data = {
    #     'fisier': csv_headers,
    #     **params
    # }
    request_data = {
        'fisier': [request_data],
        **params
    }
    response = requests.post(f'{URL}/{create_awb_url}', data=request_data)
    return response.text


# test

# print(tracking_awb_list(['2322000120065']))


data = {
    'serviciu': 'Cont Colector',
    'localitate_dest': 'Vrancea',
    'judet_dest': 'judet_dest',
    'plicuri': 1,
    'colete': 1,
    'greutate': 1,
    'lungime': 1,
    'latime': 1,
    'inaltime': 1,
    'val_decl': 1,
    'plata_ramburs': 'plata_ramburs',
    'optiuni': 'B'
}
# print(get_tariff(**data))

data = {
    'pers_contact': 'pers_contact',
    'tel': 'tel',
    'email': 'email@mail.com',
    'greutate': 10,
    'inaltime': 1,
    'lungime': 1,
    'latime': 1,
    'ora_ridicare': '16:00'
}
# print(create_order(**data))


# print(get_awb('2322000120065'))

# AWB id-s
# print(get_orders('17.11.2020'))


# data = {
#     'tip_serviciu': '1',
#     'iban': '2',
#     'nr_plicuri': '3',
#     'nr_colete': '4',
#     'greutate': '5',
#     'plata_expeditie': '6',
#     'ramburs_bani': '7',
#     'plata_ramburs_la': '8',
#     'nume_destinatar': '9',
#     'telefon': '10',
#     'judet': '11',
#     'localitate': '12',
#     'strada': '13',
#     'cod_postal': '14'
# }
# print(create_awb(**data))



import csv
import io


def normalise_fields(fields: list):
    result_fields = []

    for field in fields:
        mapping = map(lambda c: c if c.isalpha() or c == ' ' else '', field)
        result_fields.append(''.join(mapping).replace(' ', '_').lower())

    return result_fields


def csv_to_json(csv_text, headers=None):
    if not headers:
        headers = normalise_fields(csv_text.split('\n')[0].split(','))
        csv_text = '\n'.join(csv_text.split('\n')[1:])

    reader = csv.DictReader(io.StringIO(csv_text), fieldnames=headers)
    json_data = list(reader)

    return json_data


def json_to_csv_file(json_data, csv_headers):
    if not isinstance(json_data, list):
        json_data = [json_data]

    csv_result = ''
    for element in json_data:
        if not csv_result:
            headers = []
            for key in element:
                headers.append(csv_headers.get(key, key))
            csv_result += ','.join(headers)
        csv_result += '\n' + ','.join(map(str, element.values()))

    return io.BytesIO(bytes(csv_result, 'utf-8'))


def text_to_list(text_data):
    return text_data.replace('"', '').split('\n')[1:-1]



import requests

from fan_courier_client.common import BaseObject
from fan_courier_client.constants import MAIN_URL
from fan_courier_client.decorators import validate
from fan_courier_client.utils import csv_to_json


class Transfer(BaseObject):
    get_transfers_url = 'export_raport_viramente_integrat.php'

    @validate({'data': {'regex': '\d\d.\d\d.\d\d\d\d'}})
    def get(self, **kwargs):
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.get_transfers_url}', data=kwargs)
        return csv_to_json(response.text)


import requests

from fan_courier_client.common import BaseObject
from .constants import MAIN_URL
from .addresses import Address
from .rates import Rate
from .awb import Awb
from .services import Service
from .remarks import Remark
from .sheets import Sheet
from .transfers import Transfer
from .orders import Order


class Client(BaseObject):
    clients_url = 'get_account_clients_integrat.php'
    def list(self):
        response = requests.post(f'{MAIN_URL}/{self.clients_url}', data=self.params)
        return response.json()

    @property
    def addresses(self):
        return Address(**self.params)

    @property
    def rates(self):
        return Rate(**self.params)

    @property
    def awb(self):
        return Awb(**self.params)

    @property
    def services(self):
        return Service(**self.params)

    @property
    def remarks(self):
        return Remark(**self.params)

    @property
    def sheets(self):
        return Sheet(**self.params)

    @property
    def transfers(self):
        return Transfer(**self.params)

    @property
    def orders(self):
        return Order(**self.params)


import requests

from fan_courier_client.common import BaseObject
from fan_courier_client.constants import MAIN_URL
from fan_courier_client.decorators import validate
from fan_courier_client.utils import csv_to_json


class Sheet(BaseObject):
    get_sheet_url = 'export_borderou_integrat.php'
    export_sheet_url = 'finalizare_borderou_integrat.php'

    @validate({'data': {'regex': '\d\d.\d\d.\d\d\d\d'}})
    def get(self, **kwargs):
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.get_sheet_url}', data=kwargs)
        return csv_to_json(response.text)

    def export(self):
        response = requests.post(f'{MAIN_URL}/{self.export_sheet_url}', data=self.params)
        return response.content


import requests

from fan_courier_client.common import BaseObject
from fan_courier_client.constants import MAIN_URL
from fan_courier_client.utils import text_to_list


class Remark(BaseObject):
    get_remarks_url = 'export_observatii_integrat.php'

    def get(self):
        response = requests.post(f'{MAIN_URL}/{self.get_remarks_url}', data=self.params)
        return text_to_list(response.text)



import requests

from fan_courier_client.common import BaseObject
from fan_courier_client.constants import MAIN_URL
from fan_courier_client.decorators import validate
from fan_courier_client.utils import csv_to_json


class Order(BaseObject):
    get_orders_url = 'export_comenzi_integrat.php'
    create_order_url = 'comanda_curier_integrat.php'

    @validate({'data': {'regex': '\d\d.\d\d.\d\d\d\d'}})
    def get(self, **kwargs):
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.get_orders_url}', data=kwargs)
        return csv_to_json(response.text)

    fields_create_validation = {
        'pers_contact': {
            'type': str,
        },
        'tel': {
            'type': str,
        },
        'email': {
            'type': str,
            'regex': '^\S+@\S+$'
        },
        'greutate': {
            'type': int,
        },
        'inaltime': {
            'type': int,
        },
        'lungime': {
            'type': int,
        },
        'latime': {
            'type': int,
        },
        'ora_ridicare': {
            'type': str,
            'regex': '\d\d:\d\d'
        },
        'nr_colete': {
            'type': int,
            'default': 1
        },
        'nr_plicuri': {
            'type': int,
            'default': 1
        }
    }

    @validate(fields_create_validation)
    def create(self, **kwargs):
        data = {
            **self.params
        }
        data.update(kwargs)
        response = requests.post(f'{MAIN_URL}/{self.create_order_url}', data=data)
        return response.text


import requests

from fan_courier_client.common import BaseObject
from fan_courier_client.constants import MAIN_URL
from fan_courier_client.decorators import validate
from fan_courier_client.utils import csv_to_json, json_to_csv_file


class Awb(BaseObject):
    get_awb_url = 'view_awb_integrat.php'
    export_awb_url = 'view_awb_integrat_pdf.php'
    create_awb_url = 'import_awb_integrat.php'
    delete_awb_url = 'delete_awb_integrat.php'
    download_awb_url = 'download_awb_scan_integrat.php'
    error_list_awb_url = 'export_lista_erori_imp_awb_integrat.php'
    download_awb_scan_url = 'download_awb_scan_integrat.php'
    tracking_awb_url = 'awb_tracking_integrat.php'
    tracking_awb_list_url = 'awb_tracking_list_integrat.php'

    def get(self, awb_id, **kwargs):
        kwargs.update(nr=awb_id)
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.get_awb_url}', data=kwargs)
        return response.content

    fields = {
        'tip_serviciu': {},
        'banca': {},
        'iban': {},
        'nr_plicuri': {},
        'nr_colete': {},
        'greutate': {},
        'plata_expeditie': {},
        'rambursbani': {},
        'plata_ramburs_la': {},
        'valoare_declarata': {},
        'persoana_contact_expeditor': {},
        'observatii': {},
        'continut': {},
        'nume_destinatar': {},
        'persoana_contact': {},
        'telefon': {},
        'fax': {},
        'email': {},
        'judet': {},
        'localitatea': {},
        'strada': {},
        'nr': {},
        'cod_postal': {},
        'bloc': {},
        'scara': {},
        'etaj': {},
        'apartament': {},
        'inaltime_pachet': {},
        'latime_pachet': {},
        'lungime_pachet': {},
        'restituire': {},
        'centru_cost': {},
        'optiuni': {},
        'packing': {},
        'date_personale': {},
    }

    nomenclatures = {
        'tip_serviciu': 'Tip serviciu',
        'banca': 'Banca',
        'iban': 'IBAN',
        'nr_plicuri': 'Nr. Plicuri',
        'nr_colete': 'Nr. Colete',
        'greutate': 'Greutate',
        'plata_expeditie': 'Plata expeditie',
        'rambursbani': 'Ramburs(bani)',
        'plata_ramburs_la': 'Plata ramburs la',
        'valoare_declarata': 'Valoare declarata',
        'persoana_contact_expeditor': 'Persoana contact expeditor',
        'observatii': 'Observatii',
        'continut': 'Continut',
        'nume_destinatar': 'Nume destinatar',
        'persoana_contact': 'Persoana contact',
        'telefon': 'Telefon',
        'fax': 'Fax',
        'email': 'Email',
        'judet': 'Judet',
        'localitatea': 'Localitatea',
        'strada': 'Strada',
        'nr': 'Nr',
        'cod_postal': 'Cod postal',
        'bloc': 'Bloc',
        'scara': 'Scara',
        'etaj': 'Etaj',
        'apartament': 'Apartament',
        'inaltime_pachet': 'Inaltime pachet',
        'latime_pachet': 'Latime pachet',
        'lungime_pachet': 'Lungime pachet',
        'restituire': 'Restituire',
        'centru_cost': 'Centru Cost',
        'optiuni': 'Optiuni',
        'packing': 'Packing',
        'date_personale': 'Date personale',
    }

    @validate(fields)
    def create(self, **kwargs):
        files = {'fisier': json_to_csv_file(kwargs, self.nomenclatures)}
        response = requests.post(f'{MAIN_URL}/{self.create_awb_url}', files=files, data=self.params)
        return csv_to_json(response.text, ['number', 'success', 'awb_id', 'tariff'])

    def export(self, awb_id, **kwargs):
        kwargs.update(nr=awb_id)
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.export_awb_url}', data=kwargs)
        return response.content

    def delete(self, awb_id):
        data = {'AWB': awb_id}
        data.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.delete_awb_url}', data=data)
        return response.text

    def tracking(self, awb_id, display_mode=5, **kwargs):
        kwargs.update(AWB=awb_id, display_mode=display_mode)
        kwargs.update(self.params)

        response = requests.post(f'{MAIN_URL}/{self.tracking_awb_url}', data=kwargs)
        return response.json() if display_mode == 5 else response.text

    def tracking_list(self, awb_list, **kwargs):
        kwargs.update(awburi=awb_list, standard=4, **self.params)
        response = requests.post(f'{MAIN_URL}/{self.tracking_awb_list_url}', data=kwargs)
        return response.json()

    def download(self, awb_id, **kwargs):
        kwargs.update(AWB=awb_id)
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.download_awb_url}', data=kwargs)
        return response.text

    def download_scan(self, awb_id, **kwargs):
        kwargs.update(AWB=awb_id)
        kwargs.update(self.params)
        response = requests.post(f'{MAIN_URL}/{self.download_awb_scan_url}', data=kwargs)
        return response.text

    def errors(self):
        response = requests.post(f'{MAIN_URL}/{self.error_list_awb_url}', data=self.params)
        return csv_to_json(response.text)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='fan_courier_client',
    version='0.2',
    description='Fan Courier Python API Client Library',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='EBS Integrator',
    author_email='office@ebs-integrator.com',
    url='https://github.com/RodiZaharadji/fan-courier-client',
    packages=find_packages(exclude=['tests*']),
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Utilities',
    ],
    python_requires=">=3.4",
    install_requires=[
        'requests'
    ],
    license='MIT',
)



import re


def validate(validation_fields):
    def decorator(func):
        def wrapper(self, **kwargs):
            for field, description in validation_fields.items():
                field_data = kwargs.get(field)

                default_value = description.get('default')
                if default_value and not field_data:
                    kwargs.update({field: default_value})
                    field_data = kwargs.get(field)

                field_type = description.get('type')
                if field_type and not isinstance(field_data, field_type):
                    raise Exception(f"'{field}' must be of the type '{description.get('type', str).__name__}'")

                choices = description.get('choices')

                if callable(choices):
                    choices = choices()

                if choices and field_data not in choices:
                    raise Exception(f"'{field}' its values are {choices}")

                regex_format = description.get('regex')
                if regex_format:
                    regex = re.compile(regex_format, re.I)
                    if not regex.match(field_data):
                        raise Exception(f"Invalid data format. '{regex_format}'")

                if field_data is None:
                    raise Exception(f"Field '{field}' is required")
            return func(self, **kwargs)
        return wrapper
    return decorator
